==> sharepy_0.3~alpha1.tar.gz: sharepy-0.3~alpha1/setup.py <==
#!/usr/bin/env python2.5
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# MA  02110-1301, USA.
#

import glob
import os
from distutils.core import setup

# files to install
inst_desktop = ['sharepy.desktop']
inst_py = ['sharepy.py', 'sharepy.glade']
pixmaps = ['pixmaps/edit.png', 'pixmaps/add.png', 'pixmaps/remove.png', \
'pixmaps/audio.png', 'pixmaps/other.png', 'pixmaps/video.png', \
'pixmaps/sharepy.png', 'pixmaps/about.png', 'pixmaps/image.png', \
'pixmaps/selectall.png','pixmaps/clear.png', 'pixmaps/ovi.png', \
'pixmaps/picasa.png', 'pixmaps/flickr.png', 'pixmaps/youtube.png']
inst_dbus = [ 'sharepy.service' ]
backup_conf  = ['sharepy-backup.conf']
inst_icon = ['sharepy.png' ]
inst_icon_sca = ['pixmaps/sharepy.png']
py_modules = ['mod_sharepy/flickr.py', 'mod_sharepy/share_on_ovi.py', \
'mod_sharepy/picasa.py', 'mod_sharepy/youtube.py', 'mod_sharepy/__init__.py']

data_files = [
  ('share/applications/hildon', inst_desktop),
  ('share/sharepy',   inst_py),
  ('share/sharepy/mod_sharepy',   py_modules),  
  ('share/sharepy/pixmaps',   pixmaps),
  ('share/icons/hicolor/26x26/hildon/',   inst_icon),
  ('share/icons/hicolor/scalable/hildon/',   inst_icon_sca),
  ('share/dbus-1/services',   inst_dbus),
  ('/etc/osso-backup/applications/',   backup_conf),
]

setup(
  name         = 'sharepy',
  version      = '0.3',
  description  = 'Share on Ovi uploader',
  author       = 'Daniel Martin Yerga',
  author_email = 'dyerga@gmail.com',
  url          = 'https://garage.maemo.org/projects/sharepy',
  data_files   = data_files
)

==> sharepy_1.0~alpha1.tar.gz: sharepy-1.0~alpha1/setup.py <==
#!/usr/bin/env python2.5
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
# MA  02110-1301, USA.
#

from distutils.core import setup

# files to install
inst_desktop = ['sharepy.desktop']
inst_py = ['sharepy.py', 'settings.py']
pixmaps = ['pixmaps/edit.png', 'pixmaps/add.png', 'pixmaps/remove.png', \
'pixmaps/audio.png', 'pixmaps/other.png', 'pixmaps/video.png', \
'pixmaps/sharepy.png', 'pixmaps/about.png', 'pixmaps/image.png', \
'pixmaps/selectall.png','pixmaps/clear.png']
inst_dbus = [ 'sharepy.service' ]
backup_conf  = ['sharepy-backup.conf']
inst_icon = ['sharepy.png']
inst_icon_sca = ['pixmaps/sharepy.png']
py_plugins = ['plugins/flickr.py', 'plugins/_plugin_manager.py', \
'plugins/picasa.py', 'plugins/youtube.py', 'plugins/__init__.py', \
'plugins/blip.py', 'plugins/slideshare.py']
icon_plugins = ['plugins/icons/flickr.png', 'plugins/icons/picasa.png', 'plugins/icons/youtube.png', 'plugins/icons/blip.png', 'plugins/icons/slideshare.png']
#'plugins/ovi.py', 'plugins/vimeo.py', 'plugins/fb.py'

data_files = [
  ('share/applications/hildon', inst_desktop),
  ('share/sharepy',   inst_py),
  ('share/sharepy/plugins',   py_plugins),  
  ('share/sharepy/plugins/icons',   icon_plugins),  
  ('share/sharepy/pixmaps',   pixmaps),
  ('share/icons/hicolor/26x26/hildon/',   inst_icon),
  ('share/icons/hicolor/scalable/hildon/',   inst_icon_sca),
  ('share/dbus-1/services',   inst_dbus),
  ('/etc/osso-backup/applications/',   backup_conf),
]

setup(
  name         = 'sharepy',
  version      = '1.0',
  description  = 'Multimedia uploader',
  author       = 'Daniel Martin Yerga',
  author_email = 'dyerga@gmail.com',
  url          = 'https://garage.maemo.org/projects/sharepy',
  data_files   = data_files
)
